@@ -1208,7 +1208,112 @@ func TestFindDeclinedLeases(t *testing.T) {
 	require.Contains(t, arguments.(map[string]interface{}), "hw-address")
 	require.Empty(t, (arguments.(map[string]interface{}))["hw-address"])
 
-	// Ensure that the DUID sent in the second command is empty.
+	// Ensure that the DUID sent in the second command is empty ("00:00:00").
+	arguments = agents.RecordedCommands[1].(*keactrl.Command).Arguments
+	require.NotNil(t, arguments)
+	require.Contains(t, arguments.(map[string]interface{}), "duid")
+	require.Equal(t, "00:00:00", (arguments.(map[string]interface{}))["duid"])
+
+	// Simulate an error in the first response. The app returning an error should
+	// be recorded, but the DHCPv6 lease should still be returned.
+	agents = agentcommtest.NewFakeAgents(mockLeasesGetDeclinedErrors, nil)
+	leases, erredApps, err = FindDeclinedLeases(db, agents)
+	require.NoError(t, err)
+	require.Len(t, erredApps, 1)
+	require.Len(t, leases, 1)
+}
+
+// Test that Stork sends a single zero DUID to Kea when searching for declined
+// leases and Kea version is less than 2.3.8.
+func TestFindDeclinedLeasesPriorKea2_3_8(t *testing.T) {
+	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	// Add a machine with the Kea app including both DHCPv4 and DHCPv6
+	// daemon with the lease_cmds hooks library loaded.
+	machine := &dbmodel.Machine{
+		ID:        0,
+		Address:   "machine",
+		AgentPort: 8080,
+	}
+	err := dbmodel.AddMachine(db, machine)
+	require.NoError(t, err)
+
+	accessPoints := []*dbmodel.AccessPoint{}
+	accessPoints = dbmodel.AppendAccessPoint(accessPoints, dbmodel.AccessPointControl, "localhost", "", 8000, true)
+	app := &dbmodel.App{
+		MachineID:    machine.ID,
+		Type:         dbmodel.AppTypeKea,
+		AccessPoints: accessPoints,
+		Meta: dbmodel.AppMeta{
+			Version: "2.3.7",
+		},
+		Daemons: []*dbmodel.Daemon{
+			{
+				Name: dbmodel.DaemonNameDHCPv4,
+				KeaDaemon: &dbmodel.KeaDaemon{
+					Config: dbmodel.NewKeaConfig(&map[string]interface{}{
+						"Dhcp4": map[string]interface{}{
+							"hooks-libraries": []interface{}{
+								map[string]interface{}{
+									"library": "libdhcp_lease_cmds.so",
+								},
+							},
+						},
+					}),
+				},
+			},
+			{
+				Name: dbmodel.DaemonNameDHCPv6,
+				KeaDaemon: &dbmodel.KeaDaemon{
+					Config: dbmodel.NewKeaConfig(&map[string]interface{}{
+						"Dhcp6": map[string]interface{}{
+							"hooks-libraries": []interface{}{
+								map[string]interface{}{
+									"library": "libdhcp_lease_cmds.so",
+								},
+							},
+						},
+					}),
+				},
+			},
+		},
+	}
+	_, err = dbmodel.AddApp(db, app)
+	require.NoError(t, err)
+
+	// Simulate Kea returning 4 leases, one in the default state and three
+	// in the declined state.
+	agents := agentcommtest.NewFakeAgents(mockLeasesGetDeclined, nil)
+
+	leases, erredApps, err := FindDeclinedLeases(db, agents)
+	require.NoError(t, err)
+	require.Empty(t, erredApps)
+
+	// One lease should be ignored and three returned.
+	require.Len(t, leases, 3)
+
+	// Basic checks if expected leases were returned.
+	for i, ipaddr := range []string{"192.0.2.2", "2001:db8:2::1", "2001:db8:2::2"} {
+		require.EqualValues(t, app.ID, leases[i].AppID)
+		require.NotNil(t, leases[i].App)
+		require.Equal(t, ipaddr, leases[i].IPAddress)
+		require.EqualValues(t, keadata.LeaseStateDeclined, leases[i].State)
+	}
+
+	// Ensure that Stork has sent two commands, one to the DHCPv4 server and one
+	// to the DHCPv6 server.
+	require.Len(t, agents.RecordedCommands, 2)
+	require.Equal(t, "lease4-get-by-hw-address", agents.RecordedCommands[0].GetCommand())
+	require.Equal(t, "lease6-get-by-duid", agents.RecordedCommands[1].GetCommand())
+
+	// Ensure that the hw-address sent in the first command is empty.
+	arguments := agents.RecordedCommands[0].(*keactrl.Command).Arguments
+	require.NotNil(t, arguments)
+	require.Contains(t, arguments.(map[string]interface{}), "hw-address")
+	require.Empty(t, (arguments.(map[string]interface{}))["hw-address"])
+
+	// Ensure that the DUID sent in the second command is empty ("0").
 	arguments = agents.RecordedCommands[1].(*keactrl.Command).Arguments
 	require.NotNil(t, arguments)
 	require.Contains(t, arguments.(map[string]interface{}), "duid")
