@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"net/http"
+	"sort"
 	"time"
 
 	"github.com/go-openapi/runtime/middleware"
@@ -53,6 +54,9 @@ func (r *RestAPI) convertSubnetToRestAPI(sn *dbmodel.Subnet) *models.Subnet {
 			}
 			if poolDetails.KeaParameters != nil {
 				pool.KeaConfigPoolParameters = &models.KeaConfigPoolParameters{
+					KeaConfigAssortedPoolParameters: models.KeaConfigAssortedPoolParameters{
+						PoolID: poolDetails.KeaParameters.PoolID,
+					},
 					KeaConfigClientClassParameters: models.KeaConfigClientClassParameters{
 						ClientClass:          storkutil.NullifyEmptyString(poolDetails.KeaParameters.ClientClass),
 						RequireClientClasses: poolDetails.KeaParameters.RequireClientClasses,
@@ -77,6 +81,9 @@ func (r *RestAPI) convertSubnetToRestAPI(sn *dbmodel.Subnet) *models.Subnet {
 			localSubnet.PrefixDelegationPools = append(localSubnet.PrefixDelegationPools, pool)
 			if prefixPoolDetails.KeaParameters != nil {
 				pool.KeaConfigPoolParameters = &models.KeaConfigPoolParameters{
+					KeaConfigAssortedPoolParameters: models.KeaConfigAssortedPoolParameters{
+						PoolID: prefixPoolDetails.KeaParameters.PoolID,
+					},
 					KeaConfigClientClassParameters: models.KeaConfigClientClassParameters{
 						ClientClass:          storkutil.NullifyEmptyString(prefixPoolDetails.KeaParameters.ClientClass),
 						RequireClientClasses: prefixPoolDetails.KeaParameters.RequireClientClasses,
@@ -352,6 +359,7 @@ func (r *RestAPI) convertSubnetFromRestAPI(restSubnet *models.Subnet) (*dbmodel.
 						ClientClass:          storkutil.NullifyEmptyString(poolDetails.KeaConfigPoolParameters.ClientClass),
 						RequireClientClasses: poolDetails.KeaConfigPoolParameters.RequireClientClasses,
 					},
+					PoolID: poolDetails.KeaConfigPoolParameters.PoolID,
 				}
 				// DHCP options.
 				pool.DHCPOptionSet, err = r.flattenDHCPOptions("", poolDetails.KeaConfigPoolParameters.Options, 0)
@@ -376,6 +384,7 @@ func (r *RestAPI) convertSubnetFromRestAPI(restSubnet *models.Subnet) (*dbmodel.
 						ClientClass:          storkutil.NullifyEmptyString(prefixPoolDetails.KeaConfigPoolParameters.ClientClass),
 						RequireClientClasses: prefixPoolDetails.KeaConfigPoolParameters.RequireClientClasses,
 					},
+					PoolID: prefixPoolDetails.KeaConfigPoolParameters.PoolID,
 				}
 				// DHCP options.
 				pool.DHCPOptionSet, err = r.flattenDHCPOptions("", prefixPoolDetails.KeaConfigPoolParameters.Options, 0)
@@ -832,24 +841,54 @@ func (r *RestAPI) GetSharedNetwork(ctx context.Context, params dhcp.GetSharedNet
 // subnet is created or updated. It fetches available DHCP daemons. It also
 // creates transaction context. If an error occurs, an http error code and
 // message are returned.
-func (r *RestAPI) commonCreateOrUpdateSubnetBegin(ctx context.Context) ([]*models.KeaDaemon, context.Context, int, string) {
+func (r *RestAPI) commonCreateOrUpdateSubnetBegin(ctx context.Context) ([]*models.KeaDaemon, []*models.SharedNetwork, []*models.SharedNetwork, []string, context.Context, int, string) {
 	// A list of Kea DHCP daemons will be needed in the user form,
 	// so the user can select which servers send the subnet to.
 	daemons, err := dbmodel.GetKeaDHCPDaemons(r.DB)
 	if err != nil {
 		msg := "Problem with fetching Kea daemons from the database"
 		log.Error(err)
-		return nil, nil, http.StatusInternalServerError, msg
+		return nil, nil, nil, nil, nil, http.StatusInternalServerError, msg
+	}
+	sharedNetworks, err := dbmodel.GetAllSharedNetworks(r.DB, 0)
+	if err != nil {
+		msg := "Problem with fetching shared networks from the database"
+		log.WithError(err).Error(msg)
+		return nil, nil, nil, nil, nil, http.StatusInternalServerError, msg
 	}
 	// Convert daemons list to REST API format and extract their configured
 	// client classes.
 	respDaemons := []*models.KeaDaemon{}
+	respClientClasses := []string{}
+	clientClassesMap := make(map[string]bool)
 	for i := range daemons {
 		if daemons[i].KeaDaemon != nil && daemons[i].KeaDaemon.Config != nil {
 			// Filter the daemons with subnet_cmds hook library.
 			if _, _, exists := daemons[i].KeaDaemon.Config.GetHookLibrary("libdhcp_subnet_cmds"); exists {
 				respDaemons = append(respDaemons, keaDaemonToRestAPI(&daemons[i]))
 			}
+			clientClasses := daemons[i].KeaDaemon.Config.GetClientClasses()
+			for _, c := range clientClasses {
+				clientClassesMap[c.Name] = true
+			}
+		}
+	}
+	// Turn the class map to a slice and sort it by a class name.
+	for c := range clientClassesMap {
+		respClientClasses = append(respClientClasses, c)
+	}
+	sort.Strings(respClientClasses)
+
+	// Append shared networks list.
+	respIPv4SharedNetworks := []*models.SharedNetwork{}
+	respIPv6SharedNetworks := []*models.SharedNetwork{}
+	for i := range sharedNetworks {
+		respSharedNetwork := r.sharedNetworkToRestAPI(&sharedNetworks[i])
+		switch respSharedNetwork.Universe {
+		case 4:
+			respIPv4SharedNetworks = append(respIPv4SharedNetworks, respSharedNetwork)
+		default:
+			respIPv6SharedNetworks = append(respIPv6SharedNetworks, respSharedNetwork)
 		}
 	}
 
@@ -858,7 +897,7 @@ func (r *RestAPI) commonCreateOrUpdateSubnetBegin(ctx context.Context) ([]*model
 	if len(respDaemons) == 0 {
 		msg := "Unable to begin transaction for adding new subnet because there are no Kea servers with subnet_cmds hooks library available"
 		log.Error(msg)
-		return nil, nil, http.StatusBadRequest, msg
+		return nil, nil, nil, nil, nil, http.StatusBadRequest, msg
 	}
 	// Create configuration context.
 	_, user := r.SessionManager.Logged(ctx)
@@ -866,9 +905,9 @@ func (r *RestAPI) commonCreateOrUpdateSubnetBegin(ctx context.Context) ([]*model
 	if err != nil {
 		msg := "Problem with creating transaction context"
 		log.WithError(err).Error(msg)
-		return nil, nil, http.StatusInternalServerError, msg
+		return nil, nil, nil, nil, nil, http.StatusInternalServerError, msg
 	}
-	return respDaemons, cctx, 0, ""
+	return respDaemons, respIPv4SharedNetworks, respIPv6SharedNetworks, respClientClasses, cctx, 0, ""
 }
 
 // Common function that implements the POST calls to apply and commit a new
@@ -882,15 +921,15 @@ func (r *RestAPI) commonCreateOrUpdateSubnetBegin(ctx context.Context) ([]*model
 // CreateSubnetSubmit) or updated (via UpdateSubnetSubmit). The apply functions
 // receive the transaction context and a pointer to the subnet. They return the
 // updated context and error. This function returns the HTTP error code if an
-// error occurs or 0 when there is no error. In addition it returns an error
-// string to be included in the HTTP response or an empty string if there is no
-// error.
-func (r *RestAPI) commonCreateOrUpdateSubnetSubmit(ctx context.Context, transactionID int64, restSubnet *models.Subnet, applyFunc func(context.Context, *dbmodel.Subnet) (context.Context, error)) (int, string) {
+// error occurs or 0 when there is no error. It also returns an ID of the
+// created or modified subnet. Finally, it returns an error string to be included
+// in the HTTP response or an empty string if there is no error.
+func (r *RestAPI) commonCreateOrUpdateSubnetSubmit(ctx context.Context, transactionID int64, restSubnet *models.Subnet, applyFunc func(context.Context, *dbmodel.Subnet) (context.Context, error)) (int, int64, string) {
 	// Make sure that the subnet information is present.
 	if restSubnet == nil {
 		msg := "Subnet information not specified"
 		log.Errorf("Problem with submitting a subnet because the subnet information is missing")
-		return http.StatusBadRequest, msg
+		return http.StatusBadRequest, 0, msg
 	}
 	// Retrieve the context from the config manager.
 	_, user := r.SessionManager.Logged(ctx)
@@ -898,7 +937,7 @@ func (r *RestAPI) commonCreateOrUpdateSubnetSubmit(ctx context.Context, transact
 	if cctx == nil {
 		msg := "Transaction expired for the subnet update"
 		log.Errorf("Problem with recovering transaction context for transaction ID %d and user ID %d", transactionID, user.ID)
-		return http.StatusNotFound, msg
+		return http.StatusNotFound, 0, msg
 	}
 
 	// Convert subnet information from REST API to database format.
@@ -906,31 +945,48 @@ func (r *RestAPI) commonCreateOrUpdateSubnetSubmit(ctx context.Context, transact
 	if err != nil {
 		msg := "Error parsing specified subnet"
 		log.WithError(err).Error(msg)
-		return http.StatusBadRequest, msg
+		return http.StatusBadRequest, 0, msg
 	}
 	err = subnet.PopulateDaemons(r.DB)
 	if err != nil {
 		msg := "Specified subnet is associated with daemons that no longer exist"
-		log.WithError(err).Error(err)
-		return http.StatusNotFound, msg
+		log.WithError(err).Error(msg)
+		return http.StatusNotFound, 0, msg
+	}
+	if restSubnet.SharedNetwork != "" {
+		subnet.SharedNetwork = &dbmodel.SharedNetwork{
+			Name: restSubnet.SharedNetwork,
+		}
 	}
 	// Apply the subnet information (create Kea commands).
 	cctx, err = applyFunc(cctx, subnet)
 	if err != nil {
 		msg := "Problem with applying subnet information"
 		log.WithError(err).Error(msg)
-		return http.StatusInternalServerError, msg
+		return http.StatusInternalServerError, 0, msg
 	}
 	// Send the commands to Kea servers.
 	cctx, err = r.ConfigManager.Commit(cctx)
 	if err != nil {
 		msg := fmt.Sprintf("Problem with committing subnet information: %s", err)
 		log.WithError(err).Error(msg)
-		return http.StatusConflict, msg
+		return http.StatusConflict, 0, msg
+	}
+	subnetID := restSubnet.ID
+	if subnetID == 0 {
+		recipe, err := config.GetRecipeForUpdate[kea.ConfigRecipe](cctx, 0)
+		if err != nil {
+			msg := "Problem recovering subnet ID from the context"
+			log.WithError(err).Error(msg)
+			return http.StatusInternalServerError, 0, msg
+		}
+		if recipe.SubnetID != nil {
+			subnetID = *recipe.SubnetID
+		}
 	}
 	// Everything ok. Cleanup and send OK to the client.
 	r.ConfigManager.Done(cctx)
-	return 0, ""
+	return 0, subnetID, ""
 }
 
 // Common function that implements the DELETE calls to cancel adding new
@@ -952,12 +1008,101 @@ func (r *RestAPI) commonCreateOrUpdateSubnetDelete(ctx context.Context, transact
 	return 0, ""
 }
 
+// Implements the POST call to create new transaction for adding a new
+// subnet (subnets/new/transaction).
+func (r *RestAPI) CreateSubnetBegin(ctx context.Context, params dhcp.CreateSubnetBeginParams) middleware.Responder {
+	// Execute the common part between create and update operations. It retrieves
+	// the daemons and creates a transaction context.
+	respDaemons, respIPv4SharedNetworks, respIPv6SharedNetworks, respClientClasses, cctx, code, msg := r.commonCreateOrUpdateSubnetBegin(ctx)
+	if code != 0 {
+		// Error case.
+		rsp := dhcp.NewCreateSubnetBeginDefault(code).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	respSubnets, err := dbmodel.GetSubnetPrefixes(r.DB)
+	if err != nil {
+		msg := "Problem with fetching subnets from the database"
+		log.WithError(err).Error(msg)
+		rsp := dhcp.NewCreateSubnetBeginDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	// Begin subnet add transaction.
+	if cctx, err = r.ConfigManager.GetKeaModule().BeginSubnetAdd(cctx); err != nil {
+		msg := "Problem with initializing transaction for creating subnet"
+		log.WithError(err).Error(msg)
+		rsp := dhcp.NewCreateSubnetBeginDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+
+	// Retrieve the generated context ID.
+	cctxID, ok := config.GetValueAsInt64(cctx, config.ContextIDKey)
+	if !ok {
+		msg := "problem with retrieving context ID for a transaction to create a subnet"
+		log.Error(msg)
+		rsp := dhcp.NewCreateSubnetBeginDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	// Remember the context, i.e. new transaction has been successfully created.
+	_ = r.ConfigManager.RememberContext(cctx, time.Minute*10)
+
+	// Return transaction ID and daemons to the user.
+	contents := &models.CreateSubnetBeginResponse{
+		ID:              cctxID,
+		Daemons:         respDaemons,
+		SharedNetworks4: respIPv4SharedNetworks,
+		SharedNetworks6: respIPv6SharedNetworks,
+		Subnets:         respSubnets,
+		ClientClasses:   respClientClasses,
+	}
+	rsp := dhcp.NewCreateSubnetBeginOK().WithPayload(contents)
+	return rsp
+}
+
+// Implements the POST call and commits a new subnet (subnets/new/transaction/{id}/submit).
+func (r *RestAPI) CreateSubnetSubmit(ctx context.Context, params dhcp.CreateSubnetSubmitParams) middleware.Responder {
+	code, subnetID, msg := r.commonCreateOrUpdateSubnetSubmit(ctx, params.ID, params.Subnet, r.ConfigManager.GetKeaModule().ApplySubnetAdd)
+	if code != 0 {
+		// Error case.
+		rsp := dhcp.NewCreateSubnetSubmitDefault(code).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	contents := &models.CreateSubnetSubmitResponse{
+		SubnetID: subnetID,
+	}
+	rsp := dhcp.NewCreateSubnetSubmitOK().WithPayload(contents)
+	return rsp
+}
+
+// Implements the DELETE call to cancel creating a subnet (subnets/new/transaction/{id}).
+// It removes the specified transaction from the config manager, if the transaction exists.
+func (r *RestAPI) CreateSubnetDelete(ctx context.Context, params dhcp.CreateSubnetDeleteParams) middleware.Responder {
+	if code, msg := r.commonCreateOrUpdateSubnetDelete(ctx, params.ID); code != 0 {
+		// Error case.
+		rsp := dhcp.NewCreateSubnetDeleteDefault(code).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	rsp := dhcp.NewCreateSubnetDeleteOK()
+	return rsp
+}
+
 // Implements the POST call to create new transaction for updating an
 // existing subnet (subnets/{subnetId}/transaction).
 func (r *RestAPI) UpdateSubnetBegin(ctx context.Context, params dhcp.UpdateSubnetBeginParams) middleware.Responder {
 	// Execute the common part between create and update operations. It retrieves
 	// the daemons and creates a transaction context.
-	respDaemons, cctx, code, msg := r.commonCreateOrUpdateSubnetBegin(ctx)
+	respDaemons, respIPv4SharedNetworks, respIPv6SharedNetworks, respClientClasses, cctx, code, msg := r.commonCreateOrUpdateSubnetBegin(ctx)
 	if code != 0 {
 		// Error case.
 		rsp := dhcp.NewUpdateSubnetBeginDefault(code).WithPayload(&models.APIError{
@@ -1028,9 +1173,12 @@ func (r *RestAPI) UpdateSubnetBegin(ctx context.Context, params dhcp.UpdateSubne
 
 	// Return transaction ID and daemons to the user.
 	contents := &models.UpdateSubnetBeginResponse{
-		ID:      cctxID,
-		Subnet:  r.convertSubnetToRestAPI(subnet),
-		Daemons: respDaemons,
+		ID:              cctxID,
+		Subnet:          r.convertSubnetToRestAPI(subnet),
+		Daemons:         respDaemons,
+		SharedNetworks4: respIPv4SharedNetworks,
+		SharedNetworks6: respIPv6SharedNetworks,
+		ClientClasses:   respClientClasses,
 	}
 	rsp := dhcp.NewUpdateSubnetBeginOK().WithPayload(contents)
 	return rsp
@@ -1038,7 +1186,7 @@ func (r *RestAPI) UpdateSubnetBegin(ctx context.Context, params dhcp.UpdateSubne
 
 // Implements the POST call and commits an updated subnet (subnets/{subnetId}/transaction/{id}/submit).
 func (r *RestAPI) UpdateSubnetSubmit(ctx context.Context, params dhcp.UpdateSubnetSubmitParams) middleware.Responder {
-	if code, msg := r.commonCreateOrUpdateSubnetSubmit(ctx, params.ID, params.Subnet, r.ConfigManager.GetKeaModule().ApplySubnetUpdate); code != 0 {
+	if code, _, msg := r.commonCreateOrUpdateSubnetSubmit(ctx, params.ID, params.Subnet, r.ConfigManager.GetKeaModule().ApplySubnetUpdate); code != 0 {
 		// Error case.
 		rsp := dhcp.NewUpdateSubnetSubmitDefault(code).WithPayload(&models.APIError{
 			Message: &msg,
@@ -1062,3 +1210,64 @@ func (r *RestAPI) UpdateSubnetDelete(ctx context.Context, params dhcp.UpdateSubn
 	rsp := dhcp.NewUpdateSubnetDeleteOK()
 	return rsp
 }
+
+// Implements the DELETE call for a subnet (subnets/{id}). It sends suitable commands
+// to the Kea servers owning the subnet. Deleting subnet is not transactional. It could be
+// implemented as a transaction with first REST API call ensuring that the subnet still
+// exists in Stork database and locking configuration changes for the daemons owning the
+// subnet. However, it seems to be too much overhead with little gain. If the subnet
+// doesn't exist this call will return an error anyway.
+func (r *RestAPI) DeleteSubnet(ctx context.Context, params dhcp.DeleteSubnetParams) middleware.Responder {
+	dbSubnet, err := dbmodel.GetSubnet(r.DB, params.ID)
+	if err != nil {
+		// Error while communicating with the database.
+		msg := fmt.Sprintf("Problem fetching subnet with ID %d from db", params.ID)
+		log.WithError(err).Error(msg)
+		rsp := dhcp.NewDeleteHostDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	if dbSubnet == nil {
+		// Host not found.
+		msg := fmt.Sprintf("Cannot find a subnet with ID %d", params.ID)
+		rsp := dhcp.NewDeleteSubnetDefault(http.StatusNotFound).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	// Create configuration context.
+	_, user := r.SessionManager.Logged(ctx)
+	cctx, err := r.ConfigManager.CreateContext(int64(user.ID))
+	if err != nil {
+		msg := "Problem with creating transaction context for deleting the subnet"
+		log.WithError(err).Error(err)
+		rsp := dhcp.NewDeleteSubnetDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	// Create Kea commands to delete the subnet.
+	cctx, err = r.ConfigManager.GetKeaModule().ApplySubnetDelete(cctx, dbSubnet)
+	if err != nil {
+		msg := "Problem with preparing commands for deleting the subnet"
+		log.WithError(err).Error(msg)
+		rsp := dhcp.NewDeleteSubnetDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	// Send the commands to Kea servers.
+	_, err = r.ConfigManager.Commit(cctx)
+	if err != nil {
+		msg := fmt.Sprintf("Problem with deleting a subnet: %s", err)
+		log.WithError(err).Error(msg)
+		rsp := dhcp.NewDeleteSubnetDefault(http.StatusConflict).WithPayload(&models.APIError{
+			Message: &msg,
+		})
+		return rsp
+	}
+	// Send OK to the client.
+	rsp := dhcp.NewDeleteSubnetOK()
+	return rsp
+}
